Output and render functions for using 'pylintR' within Shiny applications and interactive Rmd documents.
pylintROutput(outputId, width = "100%", height = "400px")renderPylintR(expr, env = parent.frame(), quoted = FALSE)
output variable to read from
a valid CSS unit (like "100%",
"400px", "auto") or a number, which will be coerced to a
string and have "px" appended
an expression that generates an output of pylint
the environment in which to evaluate expr
whether expr is a quoted expression
(with quote()); this is useful if you want to save an expression
in a variable
pylintROutput returns an output element that can be included
in a Shiny UI definition, and renderPylintR returns a
shiny.render.function object that can be included in a Shiny
server definition.